@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright (C) 2011 Romain Gauthier <romain.gauthier@masteri2l.org>
+# Copyright (C) 2011 Laurent Peuch <cortex@worlddomination.be>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,6 +15,9 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+# Import from the standard library
+from sys import version_info
+
 # Import from feedstail
 from utils import Storage
 
@@ -25,9 +29,13 @@ class Config(Storage):
         # default values
         self.interval = 60 * 15 # 15 min
         self.oneshot = False
-        self.format = u'Title: {title}'
         self.key = 'id'
         self.reverse = False
 
+        if version_info < (2, 6):
+            self.format = u'Title: %(title)s'
+        else:
+            self.format = u'Title: {title}'
+
 
 config = Config()
